###R Workshop with Michel Belyk, November 2014###

setwd("/Users/belykm/Dropbox/R workshop") #set this to your own working directory
getwd()
load("R workshop.Rdata") 
ls()

#ANOVAs (one way, covariate, factorial, etc.) are special cases of linear models
#hence ANOVAs in R take the form of the general linear model
#the basic idea is to build two sets of models of the data
#a full model with all of your experimental variables
#and a reduced model that has one variable missing
#the difference in the explanatory power of these models tells you how important the missing variable was
#if you need more, please see a textbook on the general linear model before continueing

###################
###Linear Models###
###################
options(contrasts=c("contr.sum","contr.poly")) #set sum-to-zero assumption 


head(dat1.melt) #peak at the long format data we made earlier
names(dat1.melt)<-c("subjects", "treatment", "response") #give the columns useful names
head(dat1.melt)

###I add an unbalanced factor here to mix things up
dat1.melt$"session"<- as.factor(rep(c("one","one","two"), times=10)) 
head(dat1.melt)

#btw, with() is a convenient function for working inside dataframes
#with(dataframe, SOME.FUNCTION()) #tells SOME.FUNCTION() to look inside dataframe
with(dat1.melt, tapply(X=response, INDEX=list(treatment,session), FUN=mean)) #means
with(dat1.melt, tapply(X=response, INDEX=list(treatment,session), FUN=sd)) #st dev
with(dat1.melt, tapply(X=response, INDEX=list(treatment,session), FUN=length))#unbalanced

#####ONE-WAY ANOVA: BETWEEN SUBJECTS#####
mod1.full<-lm(response~1+treatment, data=dat1.melt) #model with intercept & one predictor
mod1.reduced<-lm(response~1, data=dat1.melt) #model with intercept only

anova(mod1.reduced, mod1.full) #compare the two models
anova(mod1.full)               #automatically does the above

mod2<-aov(response~1+treatment, data=dat1.melt) #aov is an alternate to lm
summary(mod2) #same result as before

#####ANCOVA: BETWEEN SUBJECTS#####
#to add covariates, we just put more terms in the model
mod3<-lm(response~1 + treatment + session, data=dat1.melt)
anova(mod3) #anova()  uses type I SS! 

#the model comparisons above looks something like this
#lm(response~1 + treatment + session, data=dat1.melt)
#lm(response~1             + session, data=dat1.melt)
#lm(response~1                      , data=dat1.melt)

mod4<-lm(response~1 + session + treatment, data=dat1.melt) #preds in reverse order
anova(mod4) #the order of terms changes the result! this seems bad.

drop1(mod3, test="F") #drop1() uses type III SS.
drop1(mod4, test="F") #the order of terms did not change the result. That's good.
#drop1() will drop each term from the model one at a time
#...and compare these reduced models with the full model
#...use this version, it's much better.

#####FACTORIAL ANOVA: BETWEEN#####
mod5<-lm(response~1+session*treatment, data=dat1.melt) # * for crossed terms. models both main effects and the interaction
mod6<-lm(response~1+treatment+session+treatment:session, data=dat1.melt) #same as above

drop1(mod5,scope=.~., test="F") #the scope=.~.argument tells R to test all terms
drop1(mod6,scope=.~., test="F") #see this is the same


#####ONE-WAY ANOVA: WITHIN#####
#now I'll switch back to aov() which has some extra features
head(dat1.melt)
mod7<-aov(response~1+treatment+Error(subjects/treatment), data=dat1.melt)
#Error() denotes a random factors (usually subjects) across which measurse are repeated
#subjects/treatment reads as "treatment nested within subjects" or "let's consider that treatment might have a different effect on different subjects"
summary(mod7)  #sadly drop1() does not work with Error()

#####Factorial ANOVA: WITHIN#####
mod8<-aov(response~1+treatment*session+Error(subjects/treatment), data=dat1.melt)
mod9<-aov(response~1+session*treatment+Error(subjects/treatment), data=dat1.melt)

summary(mod8) #remember that order matters with aov!
summary(mod9) 
#for the first term type I and III SS are identical
#hence run both orders and take F & p-values from the first term of each
#notice that the interaction is always the same, since it is always evaluated last
#this seems sloppy, but I purposely designed us a sloppy data set
#later we will learn about more modern approaches to linear mixed models in the package lme4

#########################
###Multiple Regression###
#########################
#all types of ANOVA are special cases of the general linear model
#we can mix categorical and linear predictors very easily.
head(ChickWeight)
class(ChickWeight$Time) #time is class numeric.it is a linear predicter
class(ChickWeight$Diet) #diet is class factor. it is a categorical pred.

mod10<-aov(weight~1+Time*Diet, data=ChickWeight)
drop1(mod10,scope=.~., test="F")
anova(mod10) #boom! You could do just about anything with this


#######################################
####Test.Assumption.Equal.Variance#### H0: Equal Variance
#######################################
bartlett.test(response~treatment, data=dat1.melt) #variance roughly equal
bartlett.test(weight~Diet, data=ChickWeight) #variance unequal


#######################################
####Test.Assumption.Normality########## H0: Normally  Distributed
#######################################
residuals(mod2)
shapiro.test(residuals(mod2)) #from synthsized data
shapiro.test(residuals(mod10))  #from ChickWeight

#plotting the model produces several diagnostic plotes
plot(mod2, which=2) #the second of which is a nice test of normality
plot(mod10, which=2)

#residuals are plotted against a normal distribution
#if they are normal they should form a straight line witha slope of 1
#the row numbers of potential outliers are marked


save.image("R workshop.Rdata") #save all of the objects in memory

